# tz-kst

This module returns current datetime in Seoul/asia

### Usage
```python
>>> from tz_kst import now
>>> now()
'2024-09-20 12:47:51'

>>> now("%Y/%m/%d")
'2024/09/20'
```

### Versions
- `0.3.0` : you can use `from tz_kst.kst import now`
- `0.5.0` : you can use `from tz_kst import now`
- `0.5.2` : included README

### Dependency
- Python Default modules
